==> embedded-permission-service-23.1.0-915.1449-sources.jar: ai/digital/deploy/permissions/config/db/PermissionServiceLiquibaseConfiguration.scala <==
package ai.digital.deploy.permissions.config.db

import ai.digital.deploy.permissions.config.profile.PermissionServiceProfileConfig.EmbeddedPermissionServiceProfile
import ai.digital.deploy.permissions.configuration.JpaDialect
import grizzled.slf4j.Logging
import liquibase.Liquibase
import liquibase.database.jvm.JdbcConnection
import liquibase.resource.ClassLoaderResourceAccessor
import org.springframework.beans.factory.annotation.Qualifier
import org.springframework.context.annotation.{Configuration, Profile}

import javax.annotation.PostConstruct
import javax.sql.DataSource

@Configuration
@Profile(Array(EmbeddedPermissionServiceProfile))
class PermissionServiceLiquibaseConfiguration(@Qualifier("permissionDataSource") permissionDataSource: DataSource)
    extends Logging {
  @PostConstruct
  def initializePermissionSchemaDatabase(): Unit = {
    logger.debug(s"Running liquibase update - Permission Service")
    updateLiquibase("classpath:/db/deploy-permission-service-changelog.yaml", permissionDataSource)
  }

  private def updateLiquibase(schema: String, dataSource: DataSource): Unit = {
    val connection = dataSource.getConnection
    try {
      val context = s"${JpaDialect.initializeDialect(dataSource).name}-${connection.getMetaData.getDatabaseMajorVersion}"
      logger.info(s"Detected liquibase context for Permission Service: $context")
      new Liquibase(
        schema,
        new ClassLoaderResourceAccessor(),
        new JdbcConnection(connection)
      ).update(s"${JpaDialect.initializeDialect(dataSource).name}-${connection.getMetaData.getDatabaseMajorVersion}")
    } finally connection.close()
  }
}

==> embedded-permission-service-23.3.0-710.113-sources.jar: ai/digital/deploy/permissions/config/db/PermissionServiceLiquibaseConfiguration.scala <==
package ai.digital.deploy.permissions.config.db

import ai.digital.deploy.permissions.config.profile.PermissionServiceProfileConfig.EmbeddedPermissionServiceProfile
import ai.digital.deploy.permissions.configuration.JpaDialect
import grizzled.slf4j.Logging
import liquibase.Liquibase
import liquibase.database.jvm.JdbcConnection
import liquibase.resource.ClassLoaderResourceAccessor
import org.springframework.beans.factory.annotation.Qualifier
import org.springframework.context.annotation.{Configuration, Profile}

import javax.annotation.PostConstruct
import javax.sql.DataSource

@Configuration
@Profile(Array(EmbeddedPermissionServiceProfile))
class PermissionServiceLiquibaseConfiguration(@Qualifier("permissionDataSource") permissionDataSource: DataSource)
    extends Logging {
  @PostConstruct
  def initializePermissionSchemaDatabase(): Unit = {
    logger.debug(s"Running liquibase update - Permission Service")
    updateLiquibase("db/deploy-permission-service-changelog.yaml", permissionDataSource)
  }

  private def updateLiquibase(schema: String, dataSource: DataSource): Unit = {
    val connection = dataSource.getConnection
    try {
      val context = s"${JpaDialect.initializeDialect(dataSource).name}-${connection.getMetaData.getDatabaseMajorVersion}"
      logger.info(s"Detected liquibase context for Permission Service: $context")
      new Liquibase(
        schema,
        new ClassLoaderResourceAccessor(),
        new JdbcConnection(connection)
      ).update(s"${JpaDialect.initializeDialect(dataSource).name}-${connection.getMetaData.getDatabaseMajorVersion}")
    } finally connection.close()
  }
}
